//	ActionScripts.js

// PlatkusWorld Software
// Copyright 2007-2012
//	by Shawn Platkus

// This file contains the functions for executing the AppleScript Actions

// Global Control Variables

var	intActionDelay = 0;
var bEmptyTrash = true;
var bCloseAllFinderWindows = true;
var bDismissDashboard = true;
var bSwitchToLoginWindow = false;
var bRestoreApps = false;
var bEjectNetworkVolumes = false;
var	bAnnounceActions = true;
var intActionCommand = 0;

var	bButtonPressed = false;
var gTimeoutTimer = null;

//
//	AppleScript Task Functions
//

function execCloseAllFinderWindows ()
{
	if (widget)
	{
		if (bAnnounceActions)
		{
			widget.system(
							"/usr/bin/osascript"+
							" -e 'say \"Closing All Finder Windows\"'",
							null);
		}

		widget.system(
						"/usr/bin/osascript"+
						" -e 'tell application \"Finder\"'"+
//						" -e 'activate'"+
						" -e 'close every window'"+
						" -e 'end tell'",
						null);
	}
}


function execEmptyTheTrash ()
{
	if (widget)
	{
		if (bAnnounceActions)
		{
			widget.system(
							"/usr/bin/osascript"+
							" -e 'say \"Emptying The Trash\"'",
							null);
		}

		widget.system(
						"/usr/bin/osascript"+
						" -e 'tell application \"Finder\"'"+
						" -e 'empty trash'"+
						" -e 'end tell'",
						null);
	}
}


function execRestoreApps ()
{
	if (widget)
	{
		if (bRestoreApps)
		{
			widget.system("/usr/bin/defaults write com.apple.loginwindow.plist TALLogoutSavesState -bool YES");
		}
		else
		{
			widget.system("/usr/bin/defaults write com.apple.loginwindow.plist TALLogoutSavesState -bool NO");
		}
	}
}


function execSleep ()
{
	if (widget)
	{
		if (bAnnounceActions)
		{
			widget.system(
							"/usr/bin/osascript"+
							" -e 'say \"Going To Sleep\"'",
							null);
		}

		widget.system(
						"/usr/bin/osascript"+
						" -e 'tell application \"Finder\"'"+
						" -e 'sleep'"+
						" -e 'end tell'",
						null);
	}
}


function execLogOut ()
{
	if (widget)
	{
		if (bAnnounceActions)
		{
			widget.system(
							"/usr/bin/osascript"+
							" -e 'say \"Logging Out\"'",
							null);
		}

		widget.system(
						"/usr/bin/osascript"+
						" -e 'tell application \"System Events\"'"+
						" -e 'log out'"+
                        " -e 'delay 1'"+
                        " -e 'key code 53'"+
						" -e 'log out'"+
						" -e 'delay 2'"+
						" -e 'key code 36'"+
						" -e 'end tell'",
						null);
		/*
		else
		{
			// Was for pressing space to not restore apps in 10.7.3 and lower
			widget.system(
							"/usr/bin/osascript"+
							" -e 'tell application \"System Events\"'"+
							" -e 'log out'"+
							" -e 'delay 2'"+
							" -e 'key code 49'"+
							" -e 'delay 1'"+
							" -e 'key code 36'"+
							" -e 'end tell'",
							null);
		}
		*/
	}
}


function execRestart ()
{
	if (widget)
	{
		if (bAnnounceActions)
		{
			widget.system(
							"/usr/bin/osascript"+
							" -e 'say \"Restarting The System\"'",
							null);
		}

		widget.system(
						"/usr/bin/osascript"+
						" -e 'tell application \"Finder\"'"+
						" -e 'ignoring application responses'"+
						" -e 'restart'"+
						" -e 'end ignoring'"+
						" -e 'end tell'",
						null);
	}
}


function execShutDown ()
{
	if (widget)
	{
		if (bAnnounceActions)
		{
			widget.system(
							"/usr/bin/osascript"+
							" -e 'say \"The System is shutting down\"'",
							null);
		}

		widget.system(
						"/usr/bin/osascript"+
						" -e 'tell application \"Finder\"'"+
						" -e 'ignoring application responses'"+
						" -e 'shut down'"+
						" -e 'end ignoring'"+
						" -e 'end tell'",
						null);
	}
}


function switchToLoginWindow ()
{
	if (widget)
	{
		if (bAnnounceActions)
		{
			widget.system(
							"/usr/bin/osascript"+
							" -e 'say \"Securing the system\"'",
							null);
		}

		widget.system("'/System/Library/CoreServices/Menu Extras/User.menu/Contents/Resources/CGSession' -suspend; sleep 7", null);
	}
}


//
//	dismissDashboard
//

function dismissDashboard ()
{
	if (widget)
	{
		//widget.openURL('');		// This will exit the Dashboard and do nothing else
        widget.openApplication("com.apple.Dock");
	}
}


//
//	isiTunesRunning
//

function isiTunesRunning ()
{
	var bIsiTunesRunning = false;

	if (widget)
	{
		var theResult = widget.system(
						"/usr/bin/osascript"+
						" -e 'tell application \"Finder\"'"+
						" -e 'set retVal to \"false\"'"+
						" -e 'set appList to name of every process'"+
						" -e 'if (appList contains \"iTunes\") then'"+
						" -e '	set retVal to \"true\"'"+
						" -e '	end if'"+
						" -e '	return retVal'"+
						" -e 'end tell'",
						null).outputString;

		if (theResult == "true\n")
		{
			bIsiTunesRunning = true;
		}
	}

	return bIsiTunesRunning;
}


//
//	pauseiTunes
//

function pauseiTunes ()
{
	if (isiTunesRunning())
	{
		if (widget)
		{
			widget.system(
							"/usr/bin/osascript"+
							" -e 'tell application \"iTunes\"'"+
							" -e '	if player state is playing then playpause'"+
							" -e 'end tell'",
							null);
		}
	}
}


//
//	ejectNetworkVolumes
//

function ejectNetworkVolumes ()
{
	if (widget)
	{
		if (bAnnounceActions)
		{
			widget.system(
							"/usr/bin/osascript"+
							" -e 'say \"Ejecting all network volumes\"'",
							null);
		}

		widget.system(
						"/usr/bin/osascript"+
						" -e 'tell application \"Finder\"'"+
						" -e 'set netDiskList to every disk whose local volume is false'"+
						" -e 'repeat with i from 1 to number of items in netDiskList'"+
						" -e '	set this_item to item i of netDiskList'"+
						" -e '	eject this_item'"+
						" -e '	delay 2'"+
						" -e 'end repeat'"+
						" -e 'end tell'",
						null);

		if (bAnnounceActions)
		{
			widget.system(
							"/usr/bin/osascript"+
							" -e 'say \"Finished ejecting network volumes\"'",
							null);
		}
	}
}
