// PowerSwitch 1.2
// PlatkusWorld Software
// Copyright 2007-2012
//	by Shawn Platkus

//	Global Constants
var	gPrefsWidth = 300;
var	gPrefsHeight = 318;
var	gFrontWidth = 70;
var	gFrontHeight = 70;

//	Global Variables
var	thePulser = null;
var	theHUDFadeIn = null;
var	theHUDFadeOut = null;
var	bMouseIn = false;

//	Setup Handlers
if (window.widget)
{
	widget.onremove = remove;
	widget.onhide = hide;
	widget.onshow = show;
}


function load()
{
	setTimeout('setupParts();',2000);
}

function remove()
{
	// widget has just been removed from the layer
	// remove any preferences as needed
	removePreferences();
}

function hide()
{
	// your widget has just been hidden stop any timers to
	// prevent cpu usage
	stopPulsing();
}

function show()
{
	// your widget has just been shown.  restart any timers
	// and adjust your interface as needed
	refreshFrontView();

	hideHUD();
}

// The rectHandler is called each interval by the Animator.  It passes in the animation values at
// this point in the animation.  The values are used to resize parts of the interface and the
// widget as a whole

function rectHandler (rectAnimation, currentRect, startingRect, finishingRect)
{
	frameResize(currentRect.right, currentRect.bottom);
}


function showBack (event)
{
	//	Set up the controls before flipping to back
	prefsToControls();

    //  Refresh the back view
    refreshBackView(event);

	//	Show the back
	var front = document.getElementById("front");
	var back = document.getElementById("back");

	if (window.widget)
		widget.prepareForTransition("ToBack");

	front.style.display="none";
	back.style.display="block";
	
	if (window.widget)
		setTimeout('widget.performTransition();', 0);

	// Once the flip to the front is complete, flipToFront resizes the widget back to its former size.
	setTimeout("flipToBack()", 750);
}

function flipToBack ()
{
	// Two AppleRect objects store the starting and finshing rectangle sizes
	var startingRect = new AppleRect (0, 0, gFrontWidth, gFrontHeight);
	var finishingRect = new AppleRect (0, 0, gPrefsWidth, gPrefsHeight);
	
	// The RectAnimation specifies the range of values and the handler to call at the animator's interval
	var currentRectAnimation = new AppleRectAnimation( startingRect, finishingRect, rectHandler );

	// The Animator is the timer for the animation
	var currentAnimator = new AppleAnimator (500, 13);
	
	// Associate the animator and animation
	currentAnimator.addAnimation(currentRectAnimation);
	
	// Once everything is set up, start the animation
	currentAnimator.start();
}
	

function flipToFront ()
{
	//	Set the Control Variables from the Controls
	controlsToPrefs();

	//	Save the Preferences
	storePreferences();

	//	Refresh The Front View
	refreshFrontView();

	//	Show the front
	var front = document.getElementById("front");
	var back = document.getElementById("back");

	if (window.widget)
		widget.prepareForTransition("ToFront");

	front.style.display="block";
	back.style.display="none";
	
	if (window.widget)
		setTimeout('widget.performTransition();', 0);
}


// flipToFront uses another AppleRectAnimation to resize the widget to its previous size

function showFront (event)
{
	var startingRect = new AppleRect (0, 0, gPrefsWidth, gPrefsHeight);
	var finishingRect = new AppleRect (0, 0, gFrontWidth, gFrontHeight);

	var currentRectAnimation = new AppleRectAnimation( startingRect, finishingRect, rectHandler );

	var currentAnimator = new AppleAnimator (500, 13);

	// Associate the animator and animation
	currentAnimator.addAnimation(currentRectAnimation);

	// Set a handler to be called when the animation is done (in this case, flip the widget to its back)
	currentAnimator.oncomplete = flipToFront;
	
	currentAnimator.start();	
}


//	frameResize
function frameResize (x,y)
{
	if(window.widget) 								// you check to see if the widget is
	{												// running in Dashboard, and then
		window.resizeTo(x, y);						// resize the widget window
	}
}


//	setupParts
function setupParts ()
{
	frameResize(gFrontWidth, gFrontHeight);

	readPreferences();

	hidePlatkusWorld();

	hideActionGrafix();

	refreshFrontView();

	hideHUD();
}


//	startCommandExecution
function startCommandExecution ()
{
	if (gTimeoutTimer)
	{
		clearTimeout(gTimeoutTimer);
	}

	gTimeoutTimer = setTimeout("performTheCommand();", (1000 * sliderTransform(intActionDelay)));
}


//	cancelCommandExecution
function cancelCommandExecution ()
{
	if (gTimeoutTimer)
	{
		clearTimeout(gTimeoutTimer);
	}

	stopPulsing();

	bButtonPressed = false;
}


//	startPulsing
function startPulsing ()
{
	if (thePulser)
	{
		thePulser.resume();
	}
	else
	{
		var fades = new Array;
		fades[0] = document.getElementById("imgButtonOn");
		fades[1] = document.getElementById("imgButtonOff");
		thePulser = new TransitionFader(fades, 1000, 10);
		thePulser.start();
	}
}


//	stopPulsing
function stopPulsing ()
{
	if (thePulser)
	{
		thePulser.pause();
		//document.getElementById("imgButtonOn").style.opacity = 0;
	}

	setTimeout('resetButtonOpacity();',1000);
}


//	resetElementOpacity
function resetElementOpacity (theElement, theOpacity)
{
	if (theElement)
	{
		theElement.style.opacity = theOpacity;
	}
}


//	resetButtonOpacity
function resetButtonOpacity ()
{
	resetElementOpacity(document.getElementById("imgButtonOn"), 0);
	resetElementOpacity(document.getElementById("imgButtonOff"), 100);
}


//	refreshBackView
function refreshBackView (event)
{
	// Set up the visibility of the controls

	var theControl;
    var theImage;

	switch (document.getElementById("popupAction").selectedIndex)
	{
		case 0:		// Disabled
		{
			// Hide all of the checkboxes and Icons
			theControl = document.getElementById ("annouceActions");
			theControl.style.visibility = "hidden";
            theImage = document.getElementById ("imgAnnounceBack");
			theImage.style.visibility = "hidden";

			theControl = document.getElementById ("closeAll");
			theControl.style.visibility = "hidden";
            theImage = document.getElementById ("imgCloseBack");
			theImage.style.visibility = "hidden";

			theControl = document.getElementById ("emptyTrash");
			theControl.style.visibility = "hidden";
            theImage = document.getElementById ("imgTrashBack");
			theImage.style.visibility = "hidden";

			theControl = document.getElementById ("ejectNetworkVolumes");
			theControl.style.visibility = "hidden";
            theImage = document.getElementById ("imgEjectBack");
			theImage.style.visibility = "hidden";

			theControl = document.getElementById ("secureSystem");
			theControl.style.visibility = "hidden";
            theImage = document.getElementById ("imgSecureBack");
			theImage.style.visibility = "hidden";

			theControl = document.getElementById ("restoreSystem");
			theControl.style.visibility = "hidden";
            theImage = document.getElementById ("imgRestoreBack");
			theImage.style.visibility = "hidden";

		} break;

		case 1:		// Enabled
		case 2:		// Sleep
		{
			// Hide the restore system checkbox and icon
			theControl = document.getElementById ("annouceActions");
			theControl.style.visibility = "visible";
            theImage = document.getElementById ("imgAnnounceBack");
			theImage.style.visibility = "visible";

			theControl = document.getElementById ("closeAll");
			theControl.style.visibility = "visible";
            theImage = document.getElementById ("imgCloseBack");
			theImage.style.visibility = "visible";

			theControl = document.getElementById ("emptyTrash");
			theControl.style.visibility = "visible";
            theImage = document.getElementById ("imgTrashBack");
			theImage.style.visibility = "visible";

			theControl = document.getElementById ("ejectNetworkVolumes");
			theControl.style.visibility = "visible";
            theImage = document.getElementById ("imgEjectBack");
			theImage.style.visibility = "visible";

			theControl = document.getElementById ("secureSystem");
			theControl.style.visibility = "visible";
            theImage = document.getElementById ("imgSecureBack");
			theImage.style.visibility = "visible";

			theControl = document.getElementById ("restoreSystem");
			theControl.style.visibility = "hidden";
            theImage = document.getElementById ("imgRestoreBack");
			theImage.style.visibility = "hidden";

		} break;

		case 3:		// Log Out
		case 4:		// Restart
		case 5:		// Shut Down
		{
			// Hide the secure system checkbox and icon
			theControl = document.getElementById ("annouceActions");
			theControl.style.visibility = "visible";
            theImage = document.getElementById ("imgAnnounceBack");
			theImage.style.visibility = "visible";

			theControl = document.getElementById ("closeAll");
			theControl.style.visibility = "visible";
            theImage = document.getElementById ("imgCloseBack");
			theImage.style.visibility = "visible";

			theControl = document.getElementById ("emptyTrash");
			theControl.style.visibility = "visible";
            theImage = document.getElementById ("imgTrashBack");
			theImage.style.visibility = "visible";

			theControl = document.getElementById ("ejectNetworkVolumes");
			theControl.style.visibility = "visible";
            theImage = document.getElementById ("imgEjectBack");
			theImage.style.visibility = "visible";

			theControl = document.getElementById ("secureSystem");
			theControl.style.visibility = "hidden";
            theImage = document.getElementById ("imgSecureBack");
			theImage.style.visibility = "hidden";

			theControl = document.getElementById ("restoreSystem");
			theControl.style.visibility = "visible";
            theImage = document.getElementById ("imgRestoreBack");
			theImage.style.visibility = "visible";

		} break;
	}
}


//	refreshFrontView
function refreshFrontView ()
{
	var imgOn, imgOff;

	imgOff = document.getElementById ("imgButtonOff");

	if (bButtonPressed)
	{
		imgOn = document.getElementById ("imgButtonOn");

		switch (intActionCommand)
		{
			case 0:
			{
				cancelCommandExecution();
				imgOff.src = "Images/Enabled-Off.png";

				// Front image will be corrected when we refresh again
				refreshFrontView();
			} break;

			case 1:
			{
				// Set the front image to Active
				imgOn.src	= "Images/Enabled-On.png";
				imgOff.src	= "Images/Enabled-Off.png";
				startPulsing();
			} break;

			case 2:
			{
				// Set the front image to Active
				imgOn.src	= "Images/Sleep-On.png";
				imgOff.src	= "Images/Sleep-Off.png";
				startPulsing();
			} break;

			case 3:
			{
				// Set the front image to Active
				imgOn.src	= "Images/Log-Out-On.png";
				imgOff.src	= "Images/Log-Out-Off.png";
				startPulsing();
			} break;

			case 4:
			{
				// Set the front image to Active
				imgOn.src	= "Images/Restart-On.png";
				imgOff.src	= "Images/Restart-Off.png";
				startPulsing();
			} break;

			case 5:
			{
				// Set the front image to Active
				imgOn.src	= "Images/Shutdown-On.png";
				imgOff.src	= "Images/Shutdown-Off.png";
				startPulsing();
			} break;
		}
	}
	else
	{
		switch (intActionCommand)
		{
			case 0:
			{
				// Set the front image to Inactive
				imgOff.src = "Images/Disabled-Off.png";
			} break;

			case 1:
			{
				// Set the front image to Active
				imgOff.src = "Images/Enabled-Off.png";
			} break;

			case 2:
			{
				// Set the front image to Active
				imgOff.src = "Images/Sleep-Off.png";
			} break;

			case 3:
			{
				// Set the front image to Active
				imgOff.src = "Images/Log-Out-Off.png";
			} break;

			case 4:
			{
				// Set the front image to Active
				imgOff.src = "Images/Restart-Off.png";
			} break;

			case 5:
			{
				// Set the front image to Active
				imgOff.src = "Images/Shutdown-Off.png";
			} break;
		}

		cancelCommandExecution();
	}

	refreshHUD();
}


//	refreshHUD
function refreshHUD ()
{
	var img;
	var intLitValue;
	var intDimValue = 0;

	if (intActionCommand > 0)
	{
		intLitValue = 1;
	}
	else
	{
		intLitValue = 0;
	}

	// Show the backdrop
	img = document.getElementById ("imgHUD");
	img.style.opacity = 1;

	// Show the Indicator Icons
	img = document.getElementById ("imgAnnounce");
	if (bAnnounceActions)
	{
		img.style.opacity = intLitValue;
	}
	else
	{
		img.style.opacity = intDimValue;
	}

	img = document.getElementById ("imgCloseWindows");
	if (bCloseAllFinderWindows)
	{
		img.style.opacity = intLitValue;
	}
	else
	{
		img.style.opacity = intDimValue;
	}

	img = document.getElementById ("imgEmptyTrash");
	if (bEmptyTrash)
	{
		img.style.opacity = intLitValue;
	}
	else
	{
		img.style.opacity = intDimValue;
	}

	img = document.getElementById ("imgEject");
	if (bEjectNetworkVolumes)
	{
		img.style.opacity = intLitValue;
	}
	else
	{
		img.style.opacity = intDimValue;
	}

	img = document.getElementById ("imgSecureSystem");
	if (bSwitchToLoginWindow && (intActionCommand < 3))
	{
		img.style.opacity = intLitValue;
	}
	else
	{
		img.style.opacity = intDimValue;
	}

	img = document.getElementById ("imgRestoreSystem");
	if (bRestoreApps && (intActionCommand >= 3))
	{
		img.style.opacity = intLitValue;
	}
	else
	{
		img.style.opacity = intDimValue;
	}

	img = document.getElementById ("imgDelay");
	if (intActionDelay > 0)
	{
		img.style.opacity = intLitValue;
	}
	else
	{
		img.style.opacity = intDimValue;
	}
}


//	hideHUD
function hideHUD ()
{
	var img;

	if (!theHUDFadeOut)
	{
		// Hide the backdrop
		img = document.getElementById ("imgHUD");
		img.style.opacity = 0;
	}

	// Hide the Indicator Icons
	img = document.getElementById ("imgAnnounce");
	img.style.opacity = 0;

	img = document.getElementById ("imgCloseWindows");
	img.style.opacity = 0;

	img = document.getElementById ("imgEmptyTrash");
	img.style.opacity = 0;

	img = document.getElementById ("imgEject");
	img.style.opacity = 0;

	img = document.getElementById ("imgSecureSystem");
	img.style.opacity = 0;

	img = document.getElementById ("imgRestoreSystem");
	img.style.opacity = 0;

	img = document.getElementById ("imgDelay");
	img.style.opacity = 0;

	img = document.getElementById ("imgScript");
	img.style.opacity = 0;
}


//	fadeInHUD
function fadeInHUD ()
{
	if (bMouseIn == true)
	{
		if (!theHUDFadeIn)
		{
			var theHUD = document.getElementById("imgHUD");
			theHUDFadeIn = new Fader(theHUD, resetHUDFadeIn, 500);
			theHUDFadeIn.fadeIn();
		}
	}
}


//	resetHUDFadeIn
function resetHUDFadeIn ()
{
	if (theHUDFadeIn)
	{
		delete theHUDFadeIn;
		theHUDFadeIn = null;
	}

	refreshHUD();
}


//	fadeOutHUD
function fadeOutHUD ()
{
	if (bMouseIn == false)
	{
		if (!theHUDFadeOut)
		{
			var theHUD = document.getElementById("imgHUD");
			theHUDFadeOut = new Fader(theHUD, resetHUDFadeOut, 500);
			hideHUD();
			theHUDFadeOut.fadeOut();
		}
	}
}


//	resetHUDFadeOut
function resetHUDFadeOut ()
{
	if (theHUDFadeOut)
	{
		delete theHUDFadeOut;
		theHUDFadeOut = null;
	}

	hideHUD();
}


//	doMouseOver
function doMouseOver (event)
{
	bMouseIn = true;

	setTimeout('fadeInHUD();',99);
}


//	doMouseOut
function doMouseOut (event)
{
	bMouseIn = false;

	setTimeout('fadeOutHUD();',99);
}


//	execTheCommand
function execTheCommand (event) 
{
	if (intActionCommand > 0)
	{
		if (bButtonPressed == true)
		{
			bButtonPressed = false;
		}
		else
		{
			bButtonPressed = true;
			startCommandExecution();
		}

		refreshFrontView();
		hideHUD();
	}
	else
	{
		bButtonPressed = false;
	}

}


//	performTheCommand
function performTheCommand(event) 
{
	if (bCloseAllFinderWindows)
	{
		execCloseAllFinderWindows();
	}

	if (bEmptyTrash)
	{
		execEmptyTheTrash();
	}

	if (bDismissDashboard)
	{
		dismissDashboard();
	}

	if (bEjectNetworkVolumes)
	{
		ejectNetworkVolumes();
	}

	if (bSwitchToLoginWindow && (intActionCommand < 3))	// Only do when staying logged in
	{
		pauseiTunes();
		switchToLoginWindow();
	}

	// bRestoreApps is checked in execRestoreApps();
	if (intActionCommand > 2) // Log Out, Restart, and Shutdown only
	{
		execRestoreApps();
	}

	switch (intActionCommand)
	{
		case 2:
		{
			execSleep();
		} break;

		case 3:
		{
			execLogOut();
		} break;

		case 4:
		{
			execRestart();
		} break;

		case 5:
		{
			execShutDown();
		} break;
	}

	bButtonPressed = false;

	refreshFrontView();
}


//
//	Controls and Preferences
//

function readPreferences ()
{
	if (window.widget)
	{
		// Read actionCommand
		intActionCommand = widget.preferenceForKey(createInstancePreferenceKey("actionCommand"));
		if (intActionCommand == null)
			intActionCommand = 0;

		// Read closeAll
		bCloseAllFinderWindows = widget.preferenceForKey(createInstancePreferenceKey("closeAll"));
		if (bCloseAllFinderWindows == null)
			bCloseAllFinderWindows = false;

		// Read emptyTrash
		bEmptyTrash = widget.preferenceForKey(createInstancePreferenceKey("emptyTrash"));
		if (bEmptyTrash == null)
			bEmptyTrash = false;

		// Read announceActions
		bAnnounceActions = widget.preferenceForKey(createInstancePreferenceKey("announceActions"));
		if (bAnnounceActions == null)
			bAnnounceActions = true;

		// Read secureSystem
		bSwitchToLoginWindow = widget.preferenceForKey(createInstancePreferenceKey("secureSystem"));
		if (bSwitchToLoginWindow == null)
			bSwitchToLoginWindow = false;

		// Read restoreSystem
		bRestoreApps = widget.preferenceForKey(createInstancePreferenceKey("restoreSystem"));
		if (bRestoreApps == null)
			bRestoreApps = false;

		// Read ejectNetVolumes
		bEjectNetworkVolumes = widget.preferenceForKey(createInstancePreferenceKey("ejectNetVolumes"));
		if (bEjectNetworkVolumes == null)
			bEjectNetworkVolumes = false;

		// Read actionDelay
		intActionDelay = widget.preferenceForKey(createInstancePreferenceKey("actionDelay"));
		if (intActionDelay == null)
			intActionDelay = 5;
	}
}


function storePreferences ()
{
	if (window.widget)
	{
		// Store actionCommand
		widget.setPreferenceForKey(intActionCommand, createInstancePreferenceKey("actionCommand"));

		// Store closeAll
		widget.setPreferenceForKey(bCloseAllFinderWindows, createInstancePreferenceKey("closeAll"));

		// Store emptyTrash
		widget.setPreferenceForKey(bEmptyTrash, createInstancePreferenceKey("emptyTrash"));

		// Store announceActions
		widget.setPreferenceForKey(bAnnounceActions, createInstancePreferenceKey("announceActions"));

		// Store secureSystem
		widget.setPreferenceForKey(bSwitchToLoginWindow, createInstancePreferenceKey("secureSystem"));

		// Store restoreSystem
		widget.setPreferenceForKey(bRestoreApps, createInstancePreferenceKey("restoreSystem"));

		// Store ejectNetVolumes
		widget.setPreferenceForKey(bEjectNetworkVolumes, createInstancePreferenceKey("ejectNetVolumes"));

		// Store actionDelay
		widget.setPreferenceForKey(intActionDelay, createInstancePreferenceKey("actionDelay"));
	}
}


function removePreferences ()
{
	if (window.widget)
	{
		// Store actionCommand
		widget.setPreferenceForKey(null, createInstancePreferenceKey("actionCommand"));

		// Store closeAll
		widget.setPreferenceForKey(null, createInstancePreferenceKey("closeAll"));

		// Store emptyTrash
		widget.setPreferenceForKey(null, createInstancePreferenceKey("emptyTrash"));

		// Store announceActions
		widget.setPreferenceForKey(null, createInstancePreferenceKey("announceActions"));

		// Store secureSystem
		widget.setPreferenceForKey(null, createInstancePreferenceKey("secureSystem"));

		// Store restoreSystem
		widget.setPreferenceForKey(null, createInstancePreferenceKey("restoreSystem"));

		// Store actionDelay
		widget.setPreferenceForKey(null, createInstancePreferenceKey("actionDelay"));
	}
}


function prefsToControls ()
{
	document.getElementById("popupAction").selectedIndex = intActionCommand;

	document.getElementById("chbxCloseAll").checked = bCloseAllFinderWindows;

	document.getElementById("chbxEmptyTrash").checked = bEmptyTrash;

	document.getElementById("chbxAnnounce").checked = bAnnounceActions;

	document.getElementById("chbxSecure").checked = bSwitchToLoginWindow;

	document.getElementById("chbxRestore").checked = bRestoreApps;

	document.getElementById("chbxEject").checked = bEjectNetworkVolumes;

	document.getElementById("slider").value = intActionDelay;

	sliderChange(document.getElementById("slider"));
}


function controlsToPrefs ()
{
	intActionCommand = document.getElementById("popupAction").selectedIndex;

	bCloseAllFinderWindows = document.getElementById("chbxCloseAll").checked;

	bEmptyTrash = document.getElementById("chbxEmptyTrash").checked;

	bAnnounceActions = document.getElementById("chbxAnnounce").checked;

	bSwitchToLoginWindow = document.getElementById("chbxSecure").checked;

	bRestoreApps = document.getElementById("chbxRestore").checked;

	bEjectNetworkVolumes = document.getElementById("chbxEject").checked;

	intActionDelay = document.getElementById("slider").value;
}


function sliderChange (elem) 
{
	document.getElementById("textDelayDisplay").innerText = sliderTransform(elem.value);
}


function sliderTransform (intValue)
{
	if (intValue > 9 && intValue < 21)
	{
		intValue = intValue * 3;
	}
	else if (intValue > 20 && intValue < 31)
	{
		intValue = intValue * 6;
	}
	else if (intValue > 30 && intValue < 41)
	{
		intValue = intValue * 10;
	}
	else if (intValue > 40 && intValue < 51)
	{
		intValue = intValue * 20;
	}
	else if (intValue > 50 && intValue < 61)
	{
		intValue = intValue * 30;
	}
	else if (intValue > 60 && intValue < 71)
	{
		intValue = intValue * 40;
	}
	else if (intValue > 70 && intValue < 81)
	{
		intValue = intValue * 50;
	}
	else if (intValue > 80 && intValue < 91)
	{
		intValue = intValue * 60;
	}
	else if (intValue > 90)
	{
		intValue = intValue * 70;
	}

	return intValue;
}


function showPlatkusWorld (event) 
{
	document.getElementById("imgPlatkusWorld").style.opacity = 1;
}

function hidePlatkusWorld (event) 
{
	document.getElementById("imgPlatkusWorld").style.opacity = 0;
}

function openPlatkusWorld (event) 
{
	if (widget)
	{
		widget.openURL('http://platkus.com/platkus/software/powerswitch.html');
	}
}


function showActionGrafix (event) 
{
	document.getElementById("imgActionGrafix").style.opacity = 1;
}

function hideActionGrafix (event) 
{
	document.getElementById("imgActionGrafix").style.opacity = 0;
}

function openActionGrafix (event) 
{
	if (widget)
	{
		widget.openURL('http://www.actiongrafix.com/powerswitch.html');
	}
}
